# lazy_testdata

testdata include chinese personal four element and offen use datetime 测试数据包含随机生成的中国公民四要素，及常用的日期时间
shell命令执行方法封装，以及常用的文件处理方法
swagger2case，通过读取swagger文档，生成规则的测试用例，如-全参数，不传，传空。仅必填项和必填项逐个校验占未实现，敬请期待。